@@ -43,8 +43,8 @@ import org.apache.hc.core5.http.io.HttpTransportMetrics;
 import org.apache.hc.core5.http.io.SessionInputBuffer;
 import org.apache.hc.core5.http.io.SessionOutputBuffer;
 import org.apache.hc.core5.util.CharArrayBuffer;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.mockito.ArgumentMatchers;
 import org.mockito.Mockito;
 
@@ -54,21 +54,21 @@ public class TestSessionInOutBuffers {
     public void testBasicBufferProperties() throws Exception {
         final SessionInputBuffer inBuffer = new SessionInputBufferImpl(16);
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(new byte[] { 1, 2 , 3});
-        Assert.assertEquals(16, inBuffer.capacity());
-        Assert.assertEquals(16, inBuffer.available());
-        Assert.assertEquals(0, inBuffer.length());
+        Assertions.assertEquals(16, inBuffer.capacity());
+        Assertions.assertEquals(16, inBuffer.available());
+        Assertions.assertEquals(0, inBuffer.length());
         inBuffer.read(inputStream);
-        Assert.assertEquals(14, inBuffer.available());
-        Assert.assertEquals(2, inBuffer.length());
+        Assertions.assertEquals(14, inBuffer.available());
+        Assertions.assertEquals(2, inBuffer.length());
 
         final SessionOutputBuffer outbuffer = new SessionOutputBufferImpl(16);
         final ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
-        Assert.assertEquals(16, outbuffer.capacity());
-        Assert.assertEquals(16, outbuffer.available());
-        Assert.assertEquals(0, outbuffer.length());
+        Assertions.assertEquals(16, outbuffer.capacity());
+        Assertions.assertEquals(16, outbuffer.available());
+        Assertions.assertEquals(0, outbuffer.length());
         outbuffer.write(new byte[] {1, 2, 3}, outputStream);
-        Assert.assertEquals(13, outbuffer.available());
-        Assert.assertEquals(3, outbuffer.length());
+        Assertions.assertEquals(13, outbuffer.available());
+        Assertions.assertEquals(3, outbuffer.length());
     }
 
     @Test
@@ -105,7 +105,7 @@ public class TestSessionInOutBuffers {
         for (final String teststr : teststrs) {
             expected += (teststr.length() + 2/*CRLF*/);
         }
-        Assert.assertEquals(expected, bytesWritten);
+        Assertions.assertEquals(expected, bytesWritten);
 
         final SessionInputBuffer inBuffer = new SessionInputBufferImpl(16);
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(outputStream.toByteArray());
@@ -113,16 +113,16 @@ public class TestSessionInOutBuffers {
         for (final String teststr : teststrs) {
             chbuffer.clear();
             inBuffer.readLine(chbuffer, inputStream);
-            Assert.assertEquals(teststr, chbuffer.toString());
+            Assertions.assertEquals(teststr, chbuffer.toString());
         }
 
         chbuffer.clear();
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         chbuffer.clear();
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         tmetrics = inBuffer.getMetrics();
         final long bytesRead = tmetrics.getBytesTransferred();
-        Assert.assertEquals(expected, bytesRead);
+        Assertions.assertEquals(expected, bytesRead);
     }
 
     @Test
@@ -140,7 +140,7 @@ public class TestSessionInOutBuffers {
         outbuffer.flush(outputStream);
 
         long bytesWritten = outbuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(8, bytesWritten);
+        Assertions.assertEquals(8, bytesWritten);
 
         final StringBuilder buffer = new StringBuilder();
         for (int i = 0; i < 14; i++) {
@@ -151,7 +151,7 @@ public class TestSessionInOutBuffers {
         outbuffer.write(buffer.toString().getBytes(StandardCharsets.US_ASCII), outputStream);
         outbuffer.flush(outputStream);
         bytesWritten = outbuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(8 + 14 +2, bytesWritten);
+        Assertions.assertEquals(8 + 14 +2, bytesWritten);
 
         buffer.setLength(0);
         for (int i = 0; i < 15; i++) {
@@ -162,7 +162,7 @@ public class TestSessionInOutBuffers {
         outbuffer.write(buffer.toString().getBytes(StandardCharsets.US_ASCII), outputStream);
         outbuffer.flush(outputStream);
         bytesWritten = outbuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(8 + 14 + 2 + 15 + 2 , bytesWritten);
+        Assertions.assertEquals(8 + 14 + 2 + 15 + 2 , bytesWritten);
 
         buffer.setLength(0);
         for (int i = 0; i < 16; i++) {
@@ -173,12 +173,12 @@ public class TestSessionInOutBuffers {
         outbuffer.write(buffer.toString().getBytes(StandardCharsets.US_ASCII), outputStream);
         outbuffer.flush(outputStream);
         bytesWritten = outbuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(8 + 14 + 2 + 15 + 2 + 16 + 2, bytesWritten);
+        Assertions.assertEquals(8 + 14 + 2 + 15 + 2 + 16 + 2, bytesWritten);
 
         outbuffer.write(new byte[] {'a'}, outputStream);
         outbuffer.flush(outputStream);
         bytesWritten = outbuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(8 + 14 + 2 + 15 + 2 + 16 + 2 + 1, bytesWritten);
+        Assertions.assertEquals(8 + 14 + 2 + 15 + 2 + 16 + 2 + 1, bytesWritten);
 
         final SessionInputBuffer inBuffer = new SessionInputBufferImpl(16);
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(outputStream.toByteArray());
@@ -186,36 +186,36 @@ public class TestSessionInOutBuffers {
         final CharArrayBuffer chbuffer = new CharArrayBuffer(16);
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals("a", chbuffer.toString());
+        Assertions.assertEquals("a", chbuffer.toString());
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals("", chbuffer.toString());
+        Assertions.assertEquals("", chbuffer.toString());
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals("\r", chbuffer.toString());
+        Assertions.assertEquals("\r", chbuffer.toString());
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals("", chbuffer.toString());
+        Assertions.assertEquals("", chbuffer.toString());
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals(s1, chbuffer.toString());
+        Assertions.assertEquals(s1, chbuffer.toString());
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals(s2, chbuffer.toString());
+        Assertions.assertEquals(s2, chbuffer.toString());
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals(s3, chbuffer.toString());
+        Assertions.assertEquals(s3, chbuffer.toString());
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals("a", chbuffer.toString());
+        Assertions.assertEquals("a", chbuffer.toString());
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         final long bytesRead = inBuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(bytesWritten, bytesRead);
+        Assertions.assertEquals(bytesWritten, bytesRead);
     }
 
     @Test
@@ -251,7 +251,7 @@ public class TestSessionInOutBuffers {
         for (final String teststr : teststrs) {
             expected += (teststr.length() + 2/*CRLF*/);
         }
-        Assert.assertEquals(expected, bytesWritten);
+        Assertions.assertEquals(expected, bytesWritten);
 
         final SessionInputBuffer inBuffer = new SessionInputBufferImpl(1024);
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(outputStream.toByteArray());
@@ -259,14 +259,14 @@ public class TestSessionInOutBuffers {
         for (final String teststr : teststrs) {
             chbuffer.clear();
             inBuffer.readLine(chbuffer, inputStream);
-            Assert.assertEquals(teststr, chbuffer.toString());
+            Assertions.assertEquals(teststr, chbuffer.toString());
         }
         chbuffer.clear();
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         chbuffer.clear();
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         final long bytesRead = inBuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(expected, bytesRead);
+        Assertions.assertEquals(expected, bytesRead);
     }
 
     @Test
@@ -291,22 +291,22 @@ public class TestSessionInOutBuffers {
         }
         outbuffer.flush(outputStream);
         final long bytesWritten = outbuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(out.length, bytesWritten);
+        Assertions.assertEquals(out.length, bytesWritten);
 
         final byte[] tmp = outputStream.toByteArray();
-        Assert.assertEquals(out.length, tmp.length);
+        Assertions.assertEquals(out.length, tmp.length);
         for (int i = 0; i < out.length; i++) {
-            Assert.assertEquals(out[i], tmp[i]);
+            Assertions.assertEquals(out[i], tmp[i]);
         }
 
         final SessionInputBuffer inBuffer = new SessionInputBufferImpl(16);
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(tmp);
 
         // these read operations will have no effect
-        Assert.assertEquals(0, inBuffer.read(null, 0, 10, inputStream));
-        Assert.assertEquals(0, inBuffer.read(null, inputStream));
+        Assertions.assertEquals(0, inBuffer.read(null, 0, 10, inputStream));
+        Assertions.assertEquals(0, inBuffer.read(null, inputStream));
         long bytesRead = inBuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(0, bytesRead);
+        Assertions.assertEquals(0, bytesRead);
 
         final byte[] in = new byte[40];
         off = 0;
@@ -324,12 +324,12 @@ public class TestSessionInOutBuffers {
             remaining -= readLen;
         }
         for (int i = 0; i < out.length; i++) {
-            Assert.assertEquals(out[i], in[i]);
+            Assertions.assertEquals(out[i], in[i]);
         }
-        Assert.assertEquals(-1, inBuffer.read(tmp, inputStream));
-        Assert.assertEquals(-1, inBuffer.read(tmp, inputStream));
+        Assertions.assertEquals(-1, inBuffer.read(tmp, inputStream));
+        Assertions.assertEquals(-1, inBuffer.read(tmp, inputStream));
         bytesRead = inBuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(out.length, bytesRead);
+        Assertions.assertEquals(out.length, bytesRead);
     }
 
     @Test
@@ -346,12 +346,12 @@ public class TestSessionInOutBuffers {
         }
         outbuffer.flush(outputStream);
         final long bytesWritten = outbuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(out.length, bytesWritten);
+        Assertions.assertEquals(out.length, bytesWritten);
 
         final byte[] tmp = outputStream.toByteArray();
-        Assert.assertEquals(out.length, tmp.length);
+        Assertions.assertEquals(out.length, tmp.length);
         for (int i = 0; i < out.length; i++) {
-            Assert.assertEquals(out[i], tmp[i]);
+            Assertions.assertEquals(out[i], tmp[i]);
         }
 
         final SessionInputBuffer inBuffer = new SessionInputBufferImpl(16);
@@ -361,12 +361,12 @@ public class TestSessionInOutBuffers {
             in[i] = (byte)inBuffer.read(inputStream);
         }
         for (int i = 0; i < out.length; i++) {
-            Assert.assertEquals(out[i], in[i]);
+            Assertions.assertEquals(out[i], in[i]);
         }
-        Assert.assertEquals(-1, inBuffer.read(inputStream));
-        Assert.assertEquals(-1, inBuffer.read(inputStream));
+        Assertions.assertEquals(-1, inBuffer.read(inputStream));
+        Assertions.assertEquals(-1, inBuffer.read(inputStream));
         final long bytesRead = inBuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(out.length, bytesRead);
+        Assertions.assertEquals(out.length, bytesRead);
     }
 
     @Test
@@ -378,7 +378,7 @@ public class TestSessionInOutBuffers {
         outbuffer.write(new byte[] {1, 2}, outputStream);
         outbuffer.write(new byte[]{3, 4}, outputStream);
         outbuffer.flush(outputStream);
-        Mockito.verify(outputStream, Mockito.times(1)).write(ArgumentMatchers.<byte[]>any(), ArgumentMatchers.anyInt(), ArgumentMatchers.anyInt());
+        Mockito.verify(outputStream, Mockito.times(1)).write(ArgumentMatchers.any(), ArgumentMatchers.anyInt(), ArgumentMatchers.anyInt());
         Mockito.verify(outputStream, Mockito.never()).write(ArgumentMatchers.anyInt());
     }
 
@@ -390,7 +390,7 @@ public class TestSessionInOutBuffers {
         outbuffer.write(2, outputStream);
         outbuffer.write(new byte[] {1, 2}, outputStream);
         outbuffer.write(new byte[]{3, 4}, outputStream);
-        Mockito.verify(outputStream, Mockito.times(2)).write(ArgumentMatchers.<byte []>any(), ArgumentMatchers.anyInt(), ArgumentMatchers.anyInt());
+        Mockito.verify(outputStream, Mockito.times(2)).write(ArgumentMatchers.any(), ArgumentMatchers.anyInt(), ArgumentMatchers.anyInt());
         Mockito.verify(outputStream, Mockito.times(2)).write(ArgumentMatchers.anyInt());
     }
 
@@ -404,17 +404,14 @@ public class TestSessionInOutBuffers {
         final CharArrayBuffer chbuffer = new CharArrayBuffer(16);
         inBuffer1.readLine(chbuffer, inputStream1);
         final long bytesRead = inBuffer1.getMetrics().getBytesTransferred();
-        Assert.assertEquals(60, bytesRead);
+        Assertions.assertEquals(60, bytesRead);
 
         // 15 char limit
         final SessionInputBuffer inBuffer2 = new SessionInputBufferImpl(5, 15);
         final InputStream inputStream2 = new ByteArrayInputStream(tmp);
-        try {
-            chbuffer.clear();
-            inBuffer2.readLine(chbuffer, inputStream2);
-            Assert.fail("MessageConstraintException expected");
-        } catch (final MessageConstraintException ex) {
-        }
+        chbuffer.clear();
+        Assertions.assertThrows(MessageConstraintException.class, () ->
+                inBuffer2.readLine(chbuffer, inputStream2));
     }
 
     @Test
@@ -427,17 +424,14 @@ public class TestSessionInOutBuffers {
         final CharArrayBuffer chbuffer = new CharArrayBuffer(16);
         inBuffer1.readLine(chbuffer, inputStream1);
         final long bytesRead = inBuffer1.getMetrics().getBytesTransferred();
-        Assert.assertEquals(13, bytesRead);
+        Assertions.assertEquals(13, bytesRead);
 
         // 10 char limit
         final SessionInputBuffer inBuffer2 = new SessionInputBufferImpl(25, 10);
         final InputStream inputStream2 = new ByteArrayInputStream(tmp);
-        try {
-            chbuffer.clear();
-            inBuffer2.readLine(chbuffer, inputStream2);
-            Assert.fail("MessageConstraintException expected");
-        } catch (final MessageConstraintException ex) {
-        }
+        chbuffer.clear();
+        Assertions.assertThrows(MessageConstraintException.class, () ->
+                inBuffer2.readLine(chbuffer, inputStream2));
     }
 
     @Test //HTTPCORE-472
@@ -448,7 +442,7 @@ public class TestSessionInOutBuffers {
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(tmp);
         final CharArrayBuffer chbuffer = new CharArrayBuffer(16);
         inBuffer1.readLine(chbuffer, inputStream);
-        Assert.assertEquals("012345678", chbuffer.toString());
+        Assertions.assertEquals("012345678", chbuffer.toString());
     }
 
     @Test
@@ -457,12 +451,12 @@ public class TestSessionInOutBuffers {
         final byte[] tmp = s.getBytes(StandardCharsets.US_ASCII);
         final SessionInputBuffer inBuffer1 = new SessionInputBufferImpl(128);
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(tmp);
-        Assert.assertEquals('a', inBuffer1.read(inputStream));
-        Assert.assertEquals('b', inBuffer1.read(inputStream));
-        Assert.assertEquals('c', inBuffer1.read(inputStream));
-        Assert.assertEquals('\r', inBuffer1.read(inputStream));
+        Assertions.assertEquals('a', inBuffer1.read(inputStream));
+        Assertions.assertEquals('b', inBuffer1.read(inputStream));
+        Assertions.assertEquals('c', inBuffer1.read(inputStream));
+        Assertions.assertEquals('\r', inBuffer1.read(inputStream));
         final CharArrayBuffer chbuffer = new CharArrayBuffer(16);
-        Assert.assertEquals(0, inBuffer1.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(0, inBuffer1.readLine(chbuffer, inputStream));
     }
 
     static final int SWISS_GERMAN_HELLO [] = {
@@ -510,7 +504,7 @@ public class TestSessionInOutBuffers {
         final long expected = ((s1.getBytes(StandardCharsets.UTF_8).length + 2)+
                 (s2.getBytes(StandardCharsets.UTF_8).length + 2) +
                 (s3.getBytes(StandardCharsets.UTF_8).length + 2)) * 10;
-        Assert.assertEquals(expected, bytesWritten);
+        Assertions.assertEquals(expected, bytesWritten);
 
         final SessionInputBuffer inBuffer = new SessionInputBufferImpl(16, StandardCharsets.UTF_8.newDecoder());
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(outputStream.toByteArray());
@@ -518,20 +512,20 @@ public class TestSessionInOutBuffers {
         for (int i = 0; i < 10; i++) {
             chbuffer.clear();
             inBuffer.readLine(chbuffer, inputStream);
-            Assert.assertEquals(s1, chbuffer.toString());
+            Assertions.assertEquals(s1, chbuffer.toString());
             chbuffer.clear();
             inBuffer.readLine(chbuffer, inputStream);
-            Assert.assertEquals(s2, chbuffer.toString());
+            Assertions.assertEquals(s2, chbuffer.toString());
             chbuffer.clear();
             inBuffer.readLine(chbuffer, inputStream);
-            Assert.assertEquals(s3, chbuffer.toString());
+            Assertions.assertEquals(s3, chbuffer.toString());
         }
         chbuffer.clear();
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         chbuffer.clear();
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         final long bytesRead = inBuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(expected, bytesRead);
+        Assertions.assertEquals(expected, bytesRead);
     }
 
     @Test
@@ -558,7 +552,7 @@ public class TestSessionInOutBuffers {
 
         chbuffer.clear();
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals(s, chbuffer.toString());
+        Assertions.assertEquals(s, chbuffer.toString());
     }
 
     @Test
@@ -579,7 +573,7 @@ public class TestSessionInOutBuffers {
         outbuffer.flush(outputStream);
         final long bytesWritten = outbuffer.getMetrics().getBytesTransferred();
         final long expected = ((s1.getBytes(StandardCharsets.ISO_8859_1).length + 2)) * 10 + 2;
-        Assert.assertEquals(expected, bytesWritten);
+        Assertions.assertEquals(expected, bytesWritten);
 
         final SessionInputBuffer inBuffer = new SessionInputBufferImpl(16, StandardCharsets.ISO_8859_1.newDecoder());
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(outputStream.toByteArray());
@@ -587,20 +581,20 @@ public class TestSessionInOutBuffers {
         for (int i = 0; i < 10; i++) {
             chbuffer.clear();
             final int len = inBuffer.readLine(chbuffer, inputStream);
-            Assert.assertEquals(len, SWISS_GERMAN_HELLO.length);
-            Assert.assertEquals(s1, chbuffer.toString());
+            Assertions.assertEquals(len, SWISS_GERMAN_HELLO.length);
+            Assertions.assertEquals(s1, chbuffer.toString());
         }
         chbuffer.clear();
-        Assert.assertEquals(0, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(0, inBuffer.readLine(chbuffer, inputStream));
         chbuffer.clear();
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         chbuffer.clear();
-        Assert.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
+        Assertions.assertEquals(-1, inBuffer.readLine(chbuffer, inputStream));
         final long bytesRead = inBuffer.getMetrics().getBytesTransferred();
-        Assert.assertEquals(expected, bytesRead);
+        Assertions.assertEquals(expected, bytesRead);
     }
 
-    @Test(expected=CharacterCodingException.class)
+    @Test
     public void testUnmappableInputActionReport() throws Exception {
         final String s = "This text contains a circumflex \u0302 !!!";
         final CharsetEncoder encoder = StandardCharsets.ISO_8859_1.newEncoder();
@@ -610,7 +604,8 @@ public class TestSessionInOutBuffers {
         final ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
         final CharArrayBuffer chbuffer = new CharArrayBuffer(32);
         chbuffer.append(s);
-        outbuffer.writeLine(chbuffer, outputStream);
+        Assertions.assertThrows(CharacterCodingException.class, () ->
+                outbuffer.writeLine(chbuffer, outputStream));
     }
 
     @Test
@@ -626,7 +621,7 @@ public class TestSessionInOutBuffers {
         outbuffer.writeLine(chbuffer, outputStream);
         outbuffer.flush(outputStream);
         final String result = new String(outputStream.toByteArray(), StandardCharsets.ISO_8859_1);
-        Assert.assertEquals("This text contains a circumflex ? !!!\r\n", result);
+        Assertions.assertEquals("This text contains a circumflex ? !!!\r\n", result);
     }
 
     @Test
@@ -642,10 +637,10 @@ public class TestSessionInOutBuffers {
         outbuffer.writeLine(chbuffer, outputStream);
         outbuffer.flush(outputStream);
         final String result = new String(outputStream.toByteArray(), StandardCharsets.ISO_8859_1);
-        Assert.assertEquals("This text contains a circumflex  !!!\r\n", result);
+        Assertions.assertEquals("This text contains a circumflex  !!!\r\n", result);
     }
 
-    @Test(expected=CharacterCodingException.class)
+    @Test
     public void testMalformedInputActionReport() throws Exception {
         final byte[] tmp = constructString(SWISS_GERMAN_HELLO).getBytes(StandardCharsets.ISO_8859_1);
         final CharsetDecoder decoder = StandardCharsets.UTF_8.newDecoder();
@@ -654,7 +649,8 @@ public class TestSessionInOutBuffers {
         final SessionInputBuffer inBuffer = new SessionInputBufferImpl(16, decoder);
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(tmp);
         final CharArrayBuffer chbuffer = new CharArrayBuffer(32);
-        inBuffer.readLine(chbuffer, inputStream);
+        Assertions.assertThrows(CharacterCodingException.class, () ->
+                inBuffer.readLine(chbuffer, inputStream));
     }
 
     @Test
@@ -667,7 +663,7 @@ public class TestSessionInOutBuffers {
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(tmp);
         final CharArrayBuffer chbuffer = new CharArrayBuffer(32);
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals("Gr\ufffdezi_z\ufffdm\ufffd", chbuffer.toString());
+        Assertions.assertEquals("Gr\ufffdezi_z\ufffdm\ufffd", chbuffer.toString());
     }
 
     @Test
@@ -680,7 +676,7 @@ public class TestSessionInOutBuffers {
         final ByteArrayInputStream inputStream = new ByteArrayInputStream(tmp);
         final CharArrayBuffer chbuffer = new CharArrayBuffer(32);
         inBuffer.readLine(chbuffer, inputStream);
-        Assert.assertEquals("Grezi_zm", chbuffer.toString());
+        Assertions.assertEquals("Grezi_zm", chbuffer.toString());
     }
 
 }
